from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryViewPublicForward(BaseModel):
    """
    types.StoryViewPublicForward
    ID: 0x9083670b
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryViewPublicForward', 'StoryViewPublicForward'] = pydantic.Field(
        'types.StoryViewPublicForward',
        alias='_'
    )

    message: "base.Message"
    blocked: typing.Optional[bool] = None
    blocked_my_stories_from: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InvokeWithMessagesRange(BaseModel):
    """
    functions.InvokeWithMessagesRange
    ID: 0x365275f2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.InvokeWithMessagesRange', 'InvokeWithMessagesRange'] = pydantic.Field(
        'functions.InvokeWithMessagesRange',
        alias='_'
    )

    range: "base.MessageRange"
    query: BaseModel



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputStorePaymentGiftPremium(BaseModel):
    """
    types.InputStorePaymentGiftPremium
    ID: 0x616f7fe8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputStorePaymentGiftPremium', 'InputStorePaymentGiftPremium'] = pydantic.Field(
        'types.InputStorePaymentGiftPremium',
        alias='_'
    )

    user_id: "base.InputUser"
    currency: str
    amount: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EncryptedMessage - Layer 181
EncryptedMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EncryptedMessage, pydantic.Tag('EncryptedMessage')],
        typing.Annotated[types.EncryptedMessageService, pydantic.Tag('EncryptedMessageService')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PhoneCallDiscardReason - Layer 181
PhoneCallDiscardReason = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PhoneCallDiscardReasonBusy, pydantic.Tag('PhoneCallDiscardReasonBusy')],
        typing.Annotated[types.PhoneCallDiscardReasonDisconnect, pydantic.Tag('PhoneCallDiscardReasonDisconnect')],
        typing.Annotated[types.PhoneCallDiscardReasonHangup, pydantic.Tag('PhoneCallDiscardReasonHangup')],
        typing.Annotated[types.PhoneCallDiscardReasonMissed, pydantic.Tag('PhoneCallDiscardReasonMissed')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockTable(BaseModel):
    """
    types.PageBlockTable
    ID: 0xbf4dea82
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockTable', 'PageBlockTable'] = pydantic.Field(
        'types.PageBlockTable',
        alias='_'
    )

    title: "base.RichText"
    rows: list["base.PageTableRow"]
    bordered: typing.Optional[bool] = None
    striped: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CheckShortName(BaseModel):
    """
    functions.stickers.CheckShortName
    ID: 0x284b3639
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stickers.CheckShortName', 'CheckShortName'] = pydantic.Field(
        'functions.stickers.CheckShortName',
        alias='_'
    )

    short_name: str



from .sent_code import SentCode
from .authorization import Authorization
from .exported_authorization import ExportedAuthorization
from .password_recovery import PasswordRecovery
from .code_type import CodeType
from .sent_code_type import SentCodeType
from .login_token import LoginToken
from .logged_out import LoggedOut



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputStickerSet - Layer 181
InputStickerSet = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputStickerSetAnimatedEmoji, pydantic.Tag('InputStickerSetAnimatedEmoji')],
        typing.Annotated[types.InputStickerSetAnimatedEmojiAnimations, pydantic.Tag('InputStickerSetAnimatedEmojiAnimations')],
        typing.Annotated[types.InputStickerSetDice, pydantic.Tag('InputStickerSetDice')],
        typing.Annotated[types.InputStickerSetEmojiChannelDefaultStatuses, pydantic.Tag('InputStickerSetEmojiChannelDefaultStatuses')],
        typing.Annotated[types.InputStickerSetEmojiDefaultStatuses, pydantic.Tag('InputStickerSetEmojiDefaultStatuses')],
        typing.Annotated[types.InputStickerSetEmojiDefaultTopicIcons, pydantic.Tag('InputStickerSetEmojiDefaultTopicIcons')],
        typing.Annotated[types.InputStickerSetEmojiGenericAnimations, pydantic.Tag('InputStickerSetEmojiGenericAnimations')],
        typing.Annotated[types.InputStickerSetEmpty, pydantic.Tag('InputStickerSetEmpty')],
        typing.Annotated[types.InputStickerSetID, pydantic.Tag('InputStickerSetID')],
        typing.Annotated[types.InputStickerSetPremiumGifts, pydantic.Tag('InputStickerSetPremiumGifts')],
        typing.Annotated[types.InputStickerSetShortName, pydantic.Tag('InputStickerSetShortName')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelMessagesFilter(BaseModel):
    """
    types.ChannelMessagesFilter
    ID: 0xcd77d957
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelMessagesFilter', 'ChannelMessagesFilter'] = pydantic.Field(
        'types.ChannelMessagesFilter',
        alias='_'
    )

    ranges: list["base.MessageRange"]
    exclude_new_messages: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Chat - Layer 181
Chat = typing.Annotated[
    typing.Union[
        typing.Annotated[types.Channel, pydantic.Tag('Channel')],
        typing.Annotated[types.ChannelForbidden, pydantic.Tag('ChannelForbidden')],
        typing.Annotated[types.Chat, pydantic.Tag('Chat')],
        typing.Annotated[types.ChatEmpty, pydantic.Tag('ChatEmpty')],
        typing.Annotated[types.ChatForbidden, pydantic.Tag('ChatForbidden')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestedPeerUser(BaseModel):
    """
    types.RequestedPeerUser
    ID: 0xd62ff46a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RequestedPeerUser', 'RequestedPeerUser'] = pydantic.Field(
        'types.RequestedPeerUser',
        alias='_'
    )

    user_id: int
    first_name: typing.Optional[str] = None
    last_name: typing.Optional[str] = None
    username: typing.Optional[str] = None
    photo: typing.Optional["base.Photo"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PrivacyKey - Layer 181
PrivacyKey = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PrivacyKeyAbout, pydantic.Tag('PrivacyKeyAbout')],
        typing.Annotated[types.PrivacyKeyAddedByPhone, pydantic.Tag('PrivacyKeyAddedByPhone')],
        typing.Annotated[types.PrivacyKeyBirthday, pydantic.Tag('PrivacyKeyBirthday')],
        typing.Annotated[types.PrivacyKeyChatInvite, pydantic.Tag('PrivacyKeyChatInvite')],
        typing.Annotated[types.PrivacyKeyForwards, pydantic.Tag('PrivacyKeyForwards')],
        typing.Annotated[types.PrivacyKeyPhoneCall, pydantic.Tag('PrivacyKeyPhoneCall')],
        typing.Annotated[types.PrivacyKeyPhoneNumber, pydantic.Tag('PrivacyKeyPhoneNumber')],
        typing.Annotated[types.PrivacyKeyPhoneP2P, pydantic.Tag('PrivacyKeyPhoneP2P')],
        typing.Annotated[types.PrivacyKeyProfilePhoto, pydantic.Tag('PrivacyKeyProfilePhoto')],
        typing.Annotated[types.PrivacyKeyStatusTimestamp, pydantic.Tag('PrivacyKeyStatusTimestamp')],
        typing.Annotated[types.PrivacyKeyVoiceMessages, pydantic.Tag('PrivacyKeyVoiceMessages')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotCommandScope - Layer 181
BotCommandScope = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BotCommandScopeChatAdmins, pydantic.Tag('BotCommandScopeChatAdmins')],
        typing.Annotated[types.BotCommandScopeChats, pydantic.Tag('BotCommandScopeChats')],
        typing.Annotated[types.BotCommandScopeDefault, pydantic.Tag('BotCommandScopeDefault')],
        typing.Annotated[types.BotCommandScopePeer, pydantic.Tag('BotCommandScopePeer')],
        typing.Annotated[types.BotCommandScopePeerAdmins, pydantic.Tag('BotCommandScopePeerAdmins')],
        typing.Annotated[types.BotCommandScopePeerUser, pydantic.Tag('BotCommandScopePeerUser')],
        typing.Annotated[types.BotCommandScopeUsers, pydantic.Tag('BotCommandScopeUsers')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# upload.CdnFile - Layer 181
CdnFile = typing.Annotated[
    typing.Union[
        typing.Annotated[types.upload.CdnFile, pydantic.Tag('upload.CdnFile')],
        typing.Annotated[types.upload.CdnFileReuploadNeeded, pydantic.Tag('upload.CdnFileReuploadNeeded')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportedChatlistInvite(BaseModel):
    """
    types.chatlists.ExportedChatlistInvite
    ID: 0x10e6e3a6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.chatlists.ExportedChatlistInvite', 'ExportedChatlistInvite'] = pydantic.Field(
        'types.chatlists.ExportedChatlistInvite',
        alias='_'
    )

    filter: "base.DialogFilter"
    invite: "base.ExportedChatlistInvite"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetEmojiKeywordsLanguages(BaseModel):
    """
    functions.messages.GetEmojiKeywordsLanguages
    ID: 0x4e9963b2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetEmojiKeywordsLanguages', 'GetEmojiKeywordsLanguages'] = pydantic.Field(
        'functions.messages.GetEmojiKeywordsLanguages',
        alias='_'
    )

    lang_codes: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockVideo(BaseModel):
    """
    types.PageBlockVideo
    ID: 0x7c8fe7b6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockVideo', 'PageBlockVideo'] = pydantic.Field(
        'types.PageBlockVideo',
        alias='_'
    )

    video_id: int
    caption: "base.PageCaption"
    autoplay: typing.Optional[bool] = None
    loop: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetAdminedPublicChannels(BaseModel):
    """
    functions.channels.GetAdminedPublicChannels
    ID: 0xf8b036af
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.GetAdminedPublicChannels', 'GetAdminedPublicChannels'] = pydantic.Field(
        'functions.channels.GetAdminedPublicChannels',
        alias='_'
    )

    by_location: typing.Optional[bool] = None
    check_limit: typing.Optional[bool] = None
    for_personal: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# User - Layer 181
User = typing.Annotated[
    typing.Union[
        typing.Annotated[types.User, pydantic.Tag('User')],
        typing.Annotated[types.UserEmpty, pydantic.Tag('UserEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# DocumentAttribute - Layer 181
DocumentAttribute = typing.Annotated[
    typing.Union[
        typing.Annotated[types.DocumentAttributeAnimated, pydantic.Tag('DocumentAttributeAnimated')],
        typing.Annotated[types.DocumentAttributeAudio, pydantic.Tag('DocumentAttributeAudio')],
        typing.Annotated[types.DocumentAttributeCustomEmoji, pydantic.Tag('DocumentAttributeCustomEmoji')],
        typing.Annotated[types.DocumentAttributeFilename, pydantic.Tag('DocumentAttributeFilename')],
        typing.Annotated[types.DocumentAttributeHasStickers, pydantic.Tag('DocumentAttributeHasStickers')],
        typing.Annotated[types.DocumentAttributeImageSize, pydantic.Tag('DocumentAttributeImageSize')],
        typing.Annotated[types.DocumentAttributeSticker, pydantic.Tag('DocumentAttributeSticker')],
        typing.Annotated[types.DocumentAttributeVideo, pydantic.Tag('DocumentAttributeVideo')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditExportedInvite(BaseModel):
    """
    functions.chatlists.EditExportedInvite
    ID: 0x653db63d
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.chatlists.EditExportedInvite', 'EditExportedInvite'] = pydantic.Field(
        'functions.chatlists.EditExportedInvite',
        alias='_'
    )

    chatlist: "base.InputChatlist"
    slug: str
    title: typing.Optional[str] = None
    peers: typing.Optional[list["base.InputPeer"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionChangeEmojiStickerSet(BaseModel):
    """
    types.ChannelAdminLogEventActionChangeEmojiStickerSet
    ID: 0x46d840ab
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionChangeEmojiStickerSet', 'ChannelAdminLogEventActionChangeEmojiStickerSet'] = pydantic.Field(
        'types.ChannelAdminLogEventActionChangeEmojiStickerSet',
        alias='_'
    )

    prev_stickerset: "base.InputStickerSet"
    new_stickerset: "base.InputStickerSet"



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types

# updates.State - Layer 181
# NOTICE: This is a workaround for pydantic. Discriminated unions doesn't work with single type in Union
# pydantic.Discriminator(base_type_discriminator)
State = typing.Union[
    typing.Annotated[types.updates.State, pydantic.Tag('updates.State')]
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Country(BaseModel):
    """
    types.help.Country
    ID: 0xc3878e23
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.Country', 'Country'] = pydantic.Field(
        'types.help.Country',
        alias='_'
    )

    iso2: str
    default_name: str
    country_codes: list["base.help.CountryCode"]
    hidden: typing.Optional[bool] = None
    name: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CountriesList(BaseModel):
    """
    types.help.CountriesList
    ID: 0x87d0759e
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.CountriesList', 'CountriesList'] = pydantic.Field(
        'types.help.CountriesList',
        alias='_'
    )

    countries: list["base.help.Country"]
    hash: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BroadcastStats(BaseModel):
    """
    types.stats.BroadcastStats
    ID: 0x396ca5fc
    Layer: 181
    """
    QUALNAME: typing.Literal['types.stats.BroadcastStats', 'BroadcastStats'] = pydantic.Field(
        'types.stats.BroadcastStats',
        alias='_'
    )

    period: "base.StatsDateRangeDays"
    followers: "base.StatsAbsValueAndPrev"
    views_per_post: "base.StatsAbsValueAndPrev"
    shares_per_post: "base.StatsAbsValueAndPrev"
    reactions_per_post: "base.StatsAbsValueAndPrev"
    views_per_story: "base.StatsAbsValueAndPrev"
    shares_per_story: "base.StatsAbsValueAndPrev"
    reactions_per_story: "base.StatsAbsValueAndPrev"
    enabled_notifications: "base.StatsPercentValue"
    growth_graph: "base.StatsGraph"
    followers_graph: "base.StatsGraph"
    mute_graph: "base.StatsGraph"
    top_hours_graph: "base.StatsGraph"
    interactions_graph: "base.StatsGraph"
    iv_interactions_graph: "base.StatsGraph"
    views_by_source_graph: "base.StatsGraph"
    new_followers_by_source_graph: "base.StatsGraph"
    languages_graph: "base.StatsGraph"
    reactions_by_emotion_graph: "base.StatsGraph"
    story_interactions_graph: "base.StatsGraph"
    story_reactions_by_emotion_graph: "base.StatsGraph"
    recent_posts_interactions: list["base.PostInteractionCounters"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class KeyboardButtonUrlAuth(BaseModel):
    """
    types.KeyboardButtonUrlAuth
    ID: 0x10b78d29
    Layer: 181
    """
    QUALNAME: typing.Literal['types.KeyboardButtonUrlAuth', 'KeyboardButtonUrlAuth'] = pydantic.Field(
        'types.KeyboardButtonUrlAuth',
        alias='_'
    )

    text: str
    url: str
    button_id: int
    fwd_text: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# contacts.Blocked - Layer 181
Blocked = typing.Annotated[
    typing.Union[
        typing.Annotated[types.contacts.Blocked, pydantic.Tag('contacts.Blocked')],
        typing.Annotated[types.contacts.BlockedSlice, pydantic.Tag('contacts.BlockedSlice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBusinessAwayMessage(BaseModel):
    """
    types.InputBusinessAwayMessage
    ID: 0x832175e0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBusinessAwayMessage', 'InputBusinessAwayMessage'] = pydantic.Field(
        'types.InputBusinessAwayMessage',
        alias='_'
    )

    shortcut_id: int
    schedule: "base.BusinessAwayMessageSchedule"
    recipients: "base.InputBusinessRecipients"
    offline_only: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.SavedRingtones - Layer 181
SavedRingtones = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.SavedRingtones, pydantic.Tag('account.SavedRingtones')],
        typing.Annotated[types.account.SavedRingtonesNotModified, pydantic.Tag('account.SavedRingtonesNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetForumTopics(BaseModel):
    """
    functions.channels.GetForumTopics
    ID: 0xde560d1
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.GetForumTopics', 'GetForumTopics'] = pydantic.Field(
        'functions.channels.GetForumTopics',
        alias='_'
    )

    channel: "base.InputChannel"
    offset_date: Datetime
    offset_id: int
    offset_topic: int
    limit: int
    q: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Message - Layer 181
Message = typing.Annotated[
    typing.Union[
        typing.Annotated[types.Message, pydantic.Tag('Message')],
        typing.Annotated[types.MessageEmpty, pydantic.Tag('MessageEmpty')],
        typing.Annotated[types.MessageService, pydantic.Tag('MessageService')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RecentStickers(BaseModel):
    """
    types.messages.RecentStickers
    ID: 0x88d37c56
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.RecentStickers', 'RecentStickers'] = pydantic.Field(
        'types.messages.RecentStickers',
        alias='_'
    )

    hash: int
    packs: list["base.StickerPack"]
    stickers: list["base.Document"]
    dates: list[int]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPaymentCredentials - Layer 181
InputPaymentCredentials = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputPaymentCredentials, pydantic.Tag('InputPaymentCredentials')],
        typing.Annotated[types.InputPaymentCredentialsApplePay, pydantic.Tag('InputPaymentCredentialsApplePay')],
        typing.Annotated[types.InputPaymentCredentialsGooglePay, pydantic.Tag('InputPaymentCredentialsGooglePay')],
        typing.Annotated[types.InputPaymentCredentialsSaved, pydantic.Tag('InputPaymentCredentialsSaved')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SavedPhoneContact(BaseModel):
    """
    types.SavedPhoneContact
    ID: 0x1142bd56
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SavedPhoneContact', 'SavedPhoneContact'] = pydantic.Field(
        'types.SavedPhoneContact',
        alias='_'
    )

    phone: str
    first_name: str
    last_name: str
    date: Datetime



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputPhoneContact(BaseModel):
    """
    types.InputPhoneContact
    ID: 0xf392b7f4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputPhoneContact', 'InputPhoneContact'] = pydantic.Field(
        'types.InputPhoneContact',
        alias='_'
    )

    client_id: int
    phone: str
    first_name: str
    last_name: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotInlineMessage - Layer 181
BotInlineMessage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BotInlineMessageMediaAuto, pydantic.Tag('BotInlineMessageMediaAuto')],
        typing.Annotated[types.BotInlineMessageMediaContact, pydantic.Tag('BotInlineMessageMediaContact')],
        typing.Annotated[types.BotInlineMessageMediaGeo, pydantic.Tag('BotInlineMessageMediaGeo')],
        typing.Annotated[types.BotInlineMessageMediaInvoice, pydantic.Tag('BotInlineMessageMediaInvoice')],
        typing.Annotated[types.BotInlineMessageMediaVenue, pydantic.Tag('BotInlineMessageMediaVenue')],
        typing.Annotated[types.BotInlineMessageMediaWebPage, pydantic.Tag('BotInlineMessageMediaWebPage')],
        typing.Annotated[types.BotInlineMessageText, pydantic.Tag('BotInlineMessageText')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBusinessGreetingMessage(BaseModel):
    """
    functions.account.UpdateBusinessGreetingMessage
    ID: 0x66cdafc4
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateBusinessGreetingMessage', 'UpdateBusinessGreetingMessage'] = pydantic.Field(
        'functions.account.UpdateBusinessGreetingMessage',
        alias='_'
    )

    message: typing.Optional["base.InputBusinessGreetingMessage"] = None



from .exported_chatlist_invite import ExportedChatlistInvite
from .exported_invites import ExportedInvites
from .chatlist_invite_already import ChatlistInviteAlready
from .chatlist_invite import ChatlistInvite
from .chatlist_updates import ChatlistUpdates



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputMedia - Layer 181
InputMedia = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputMediaContact, pydantic.Tag('InputMediaContact')],
        typing.Annotated[types.InputMediaDice, pydantic.Tag('InputMediaDice')],
        typing.Annotated[types.InputMediaDocument, pydantic.Tag('InputMediaDocument')],
        typing.Annotated[types.InputMediaDocumentExternal, pydantic.Tag('InputMediaDocumentExternal')],
        typing.Annotated[types.InputMediaEmpty, pydantic.Tag('InputMediaEmpty')],
        typing.Annotated[types.InputMediaGame, pydantic.Tag('InputMediaGame')],
        typing.Annotated[types.InputMediaGeoLive, pydantic.Tag('InputMediaGeoLive')],
        typing.Annotated[types.InputMediaGeoPoint, pydantic.Tag('InputMediaGeoPoint')],
        typing.Annotated[types.InputMediaInvoice, pydantic.Tag('InputMediaInvoice')],
        typing.Annotated[types.InputMediaPhoto, pydantic.Tag('InputMediaPhoto')],
        typing.Annotated[types.InputMediaPhotoExternal, pydantic.Tag('InputMediaPhotoExternal')],
        typing.Annotated[types.InputMediaPoll, pydantic.Tag('InputMediaPoll')],
        typing.Annotated[types.InputMediaStory, pydantic.Tag('InputMediaStory')],
        typing.Annotated[types.InputMediaUploadedDocument, pydantic.Tag('InputMediaUploadedDocument')],
        typing.Annotated[types.InputMediaUploadedPhoto, pydantic.Tag('InputMediaUploadedPhoto')],
        typing.Annotated[types.InputMediaVenue, pydantic.Tag('InputMediaVenue')],
        typing.Annotated[types.InputMediaWebPage, pydantic.Tag('InputMediaWebPage')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputEncryptedFile - Layer 181
InputEncryptedFile = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputEncryptedFile, pydantic.Tag('InputEncryptedFile')],
        typing.Annotated[types.InputEncryptedFileBigUploaded, pydantic.Tag('InputEncryptedFileBigUploaded')],
        typing.Annotated[types.InputEncryptedFileEmpty, pydantic.Tag('InputEncryptedFileEmpty')],
        typing.Annotated[types.InputEncryptedFileUploaded, pydantic.Tag('InputEncryptedFileUploaded')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class FileCdnRedirect(BaseModel):
    """
    types.upload.FileCdnRedirect
    ID: 0xf18cda44
    Layer: 181
    """
    QUALNAME: typing.Literal['types.upload.FileCdnRedirect', 'FileCdnRedirect'] = pydantic.Field(
        'types.upload.FileCdnRedirect',
        alias='_'
    )

    dc_id: int
    file_token: Bytes
    encryption_key: Bytes
    encryption_iv: Bytes
    file_hashes: list["base.FileHash"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmojiGroup - Layer 181
EmojiGroup = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EmojiGroup, pydantic.Tag('EmojiGroup')],
        typing.Annotated[types.EmojiGroupGreeting, pydantic.Tag('EmojiGroupGreeting')],
        typing.Annotated[types.EmojiGroupPremium, pydantic.Tag('EmojiGroupPremium')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateChannelParticipant(BaseModel):
    """
    types.UpdateChannelParticipant
    ID: 0x985d3abb
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateChannelParticipant', 'UpdateChannelParticipant'] = pydantic.Field(
        'types.UpdateChannelParticipant',
        alias='_'
    )

    channel_id: int
    date: Datetime
    actor_id: int
    user_id: int
    qts: int
    via_chatlist: typing.Optional[bool] = None
    prev_participant: typing.Optional["base.ChannelParticipant"] = None
    new_participant: typing.Optional["base.ChannelParticipant"] = None
    invite: typing.Optional["base.ExportedChatInvite"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatePasswordSettings(BaseModel):
    """
    functions.account.UpdatePasswordSettings
    ID: 0xa59b102f
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdatePasswordSettings', 'UpdatePasswordSettings'] = pydantic.Field(
        'functions.account.UpdatePasswordSettings',
        alias='_'
    )

    password: "base.InputCheckPasswordSRP"
    new_settings: "base.account.PasswordInputSettings"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmojiGroupGreeting(BaseModel):
    """
    types.EmojiGroupGreeting
    ID: 0x80d26cc7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EmojiGroupGreeting', 'EmojiGroupGreeting'] = pydantic.Field(
        'types.EmojiGroupGreeting',
        alias='_'
    )

    title: str
    icon_emoji_id: int
    emoticons: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmojiKeywordDeleted(BaseModel):
    """
    types.EmojiKeywordDeleted
    ID: 0x236df622
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EmojiKeywordDeleted', 'EmojiKeywordDeleted'] = pydantic.Field(
        'types.EmojiKeywordDeleted',
        alias='_'
    )

    keyword: str
    emoticons: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetLeaveChatlistSuggestions(BaseModel):
    """
    functions.chatlists.GetLeaveChatlistSuggestions
    ID: 0xfdbcd714
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.chatlists.GetLeaveChatlistSuggestions', 'GetLeaveChatlistSuggestions'] = pydantic.Field(
        'functions.chatlists.GetLeaveChatlistSuggestions',
        alias='_'
    )

    chatlist: "base.InputChatlist"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SetBotShippingResults(BaseModel):
    """
    functions.messages.SetBotShippingResults
    ID: 0xe5f672fa
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.SetBotShippingResults', 'SetBotShippingResults'] = pydantic.Field(
        'functions.messages.SetBotShippingResults',
        alias='_'
    )

    query_id: int
    error: typing.Optional[str] = None
    shipping_options: typing.Optional[list["base.ShippingOption"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentCodeTypeSetUpEmailRequired(BaseModel):
    """
    types.auth.SentCodeTypeSetUpEmailRequired
    ID: 0xa5491dea
    Layer: 181
    """
    QUALNAME: typing.Literal['types.auth.SentCodeTypeSetUpEmailRequired', 'SentCodeTypeSetUpEmailRequired'] = pydantic.Field(
        'types.auth.SentCodeTypeSetUpEmailRequired',
        alias='_'
    )

    apple_signin_allowed: typing.Optional[bool] = None
    google_signin_allowed: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ContactBirthdays(BaseModel):
    """
    types.contacts.ContactBirthdays
    ID: 0x114ff30d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.contacts.ContactBirthdays', 'ContactBirthdays'] = pydantic.Field(
        'types.contacts.ContactBirthdays',
        alias='_'
    )

    contacts: list["base.ContactBirthday"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBotWebhookJSONQuery(BaseModel):
    """
    types.UpdateBotWebhookJSONQuery
    ID: 0x9b9240a6
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateBotWebhookJSONQuery', 'UpdateBotWebhookJSONQuery'] = pydantic.Field(
        'types.UpdateBotWebhookJSONQuery',
        alias='_'
    )

    query_id: int
    data: "base.DataJSON"
    timeout: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BaseTheme - Layer 181
BaseTheme = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BaseThemeArctic, pydantic.Tag('BaseThemeArctic')],
        typing.Annotated[types.BaseThemeClassic, pydantic.Tag('BaseThemeClassic')],
        typing.Annotated[types.BaseThemeDay, pydantic.Tag('BaseThemeDay')],
        typing.Annotated[types.BaseThemeNight, pydantic.Tag('BaseThemeNight')],
        typing.Annotated[types.BaseThemeTinted, pydantic.Tag('BaseThemeTinted')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputBotInlineMessageID - Layer 181
InputBotInlineMessageID = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputBotInlineMessageID, pydantic.Tag('InputBotInlineMessageID')],
        typing.Annotated[types.InputBotInlineMessageID64, pydantic.Tag('InputBotInlineMessageID64')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputCollectible - Layer 181
InputCollectible = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputCollectiblePhone, pydantic.Tag('InputCollectiblePhone')],
        typing.Annotated[types.InputCollectibleUsername, pydantic.Tag('InputCollectibleUsername')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# account.WallPapers - Layer 181
WallPapers = typing.Annotated[
    typing.Union[
        typing.Annotated[types.account.WallPapers, pydantic.Tag('account.WallPapers')],
        typing.Annotated[types.account.WallPapersNotModified, pydantic.Tag('account.WallPapersNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateBusinessLocation(BaseModel):
    """
    functions.account.UpdateBusinessLocation
    ID: 0x9e6b131a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UpdateBusinessLocation', 'UpdateBusinessLocation'] = pydantic.Field(
        'functions.account.UpdateBusinessLocation',
        alias='_'
    )

    geo_point: typing.Optional["base.InputGeoPoint"] = None
    address: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EditPhoto(BaseModel):
    """
    functions.channels.EditPhoto
    ID: 0xf12e57c9
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.EditPhoto', 'EditPhoto'] = pydantic.Field(
        'functions.channels.EditPhoto',
        alias='_'
    )

    channel: "base.InputChannel"
    photo: "base.InputChatPhoto"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InitConnection(BaseModel):
    """
    functions.InitConnection
    ID: 0xc1cd5ea9
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.InitConnection', 'InitConnection'] = pydantic.Field(
        'functions.InitConnection',
        alias='_'
    )

    api_id: int
    device_model: str
    system_version: str
    app_version: str
    system_lang_code: str
    lang_pack: str
    lang_code: str
    query: BaseModel
    proxy: typing.Optional["base.InputClientProxy"] = None
    params: typing.Optional["base.JSONValue"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PageListOrderedItem - Layer 181
PageListOrderedItem = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PageListOrderedItemBlocks, pydantic.Tag('PageListOrderedItemBlocks')],
        typing.Annotated[types.PageListOrderedItemText, pydantic.Tag('PageListOrderedItemText')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# EmailVerification - Layer 181
EmailVerification = typing.Annotated[
    typing.Union[
        typing.Annotated[types.EmailVerificationApple, pydantic.Tag('EmailVerificationApple')],
        typing.Annotated[types.EmailVerificationCode, pydantic.Tag('EmailVerificationCode')],
        typing.Annotated[types.EmailVerificationGoogle, pydantic.Tag('EmailVerificationGoogle')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateMoveStickerSetToTop(BaseModel):
    """
    types.UpdateMoveStickerSetToTop
    ID: 0x86fccf85
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateMoveStickerSetToTop', 'UpdateMoveStickerSetToTop'] = pydantic.Field(
        'types.UpdateMoveStickerSetToTop',
        alias='_'
    )

    stickerset: int
    masks: typing.Optional[bool] = None
    emojis: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputKeyboardButtonUrlAuth(BaseModel):
    """
    types.InputKeyboardButtonUrlAuth
    ID: 0xd02e7fd4
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputKeyboardButtonUrlAuth', 'InputKeyboardButtonUrlAuth'] = pydantic.Field(
        'types.InputKeyboardButtonUrlAuth',
        alias='_'
    )

    text: str
    url: str
    bot: "base.InputUser"
    request_write_access: typing.Optional[bool] = None
    fwd_text: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LangPackLanguage(BaseModel):
    """
    types.LangPackLanguage
    ID: 0xeeca5ce3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.LangPackLanguage', 'LangPackLanguage'] = pydantic.Field(
        'types.LangPackLanguage',
        alias='_'
    )

    name: str
    native_name: str
    lang_code: str
    plural_code: str
    strings_count: int
    translated_count: int
    translations_url: str
    official: typing.Optional[bool] = None
    rtl: typing.Optional[bool] = None
    beta: typing.Optional[bool] = None
    base_lang_code: typing.Optional[str] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPhoto - Layer 181
InputPhoto = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputPhoto, pydantic.Tag('InputPhoto')],
        typing.Annotated[types.InputPhotoEmpty, pydantic.Tag('InputPhotoEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SendMessageAction - Layer 181
SendMessageAction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.SendMessageCancelAction, pydantic.Tag('SendMessageCancelAction')],
        typing.Annotated[types.SendMessageChooseContactAction, pydantic.Tag('SendMessageChooseContactAction')],
        typing.Annotated[types.SendMessageChooseStickerAction, pydantic.Tag('SendMessageChooseStickerAction')],
        typing.Annotated[types.SendMessageEmojiInteraction, pydantic.Tag('SendMessageEmojiInteraction')],
        typing.Annotated[types.SendMessageEmojiInteractionSeen, pydantic.Tag('SendMessageEmojiInteractionSeen')],
        typing.Annotated[types.SendMessageGamePlayAction, pydantic.Tag('SendMessageGamePlayAction')],
        typing.Annotated[types.SendMessageGeoLocationAction, pydantic.Tag('SendMessageGeoLocationAction')],
        typing.Annotated[types.SendMessageHistoryImportAction, pydantic.Tag('SendMessageHistoryImportAction')],
        typing.Annotated[types.SendMessageRecordAudioAction, pydantic.Tag('SendMessageRecordAudioAction')],
        typing.Annotated[types.SendMessageRecordRoundAction, pydantic.Tag('SendMessageRecordRoundAction')],
        typing.Annotated[types.SendMessageRecordVideoAction, pydantic.Tag('SendMessageRecordVideoAction')],
        typing.Annotated[types.SendMessageTypingAction, pydantic.Tag('SendMessageTypingAction')],
        typing.Annotated[types.SendMessageUploadAudioAction, pydantic.Tag('SendMessageUploadAudioAction')],
        typing.Annotated[types.SendMessageUploadDocumentAction, pydantic.Tag('SendMessageUploadDocumentAction')],
        typing.Annotated[types.SendMessageUploadPhotoAction, pydantic.Tag('SendMessageUploadPhotoAction')],
        typing.Annotated[types.SendMessageUploadRoundAction, pydantic.Tag('SendMessageUploadRoundAction')],
        typing.Annotated[types.SendMessageUploadVideoAction, pydantic.Tag('SendMessageUploadVideoAction')],
        typing.Annotated[types.SpeakingInGroupCallAction, pydantic.Tag('SpeakingInGroupCallAction')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# auth.LoginToken - Layer 181
LoginToken = typing.Annotated[
    typing.Union[
        typing.Annotated[types.auth.LoginToken, pydantic.Tag('auth.LoginToken')],
        typing.Annotated[types.auth.LoginTokenMigrateTo, pydantic.Tag('auth.LoginTokenMigrateTo')],
        typing.Annotated[types.auth.LoginTokenSuccess, pydantic.Tag('auth.LoginTokenSuccess')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ReportReason - Layer 181
ReportReason = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputReportReasonChildAbuse, pydantic.Tag('InputReportReasonChildAbuse')],
        typing.Annotated[types.InputReportReasonCopyright, pydantic.Tag('InputReportReasonCopyright')],
        typing.Annotated[types.InputReportReasonFake, pydantic.Tag('InputReportReasonFake')],
        typing.Annotated[types.InputReportReasonGeoIrrelevant, pydantic.Tag('InputReportReasonGeoIrrelevant')],
        typing.Annotated[types.InputReportReasonIllegalDrugs, pydantic.Tag('InputReportReasonIllegalDrugs')],
        typing.Annotated[types.InputReportReasonOther, pydantic.Tag('InputReportReasonOther')],
        typing.Annotated[types.InputReportReasonPersonalDetails, pydantic.Tag('InputReportReasonPersonalDetails')],
        typing.Annotated[types.InputReportReasonPornography, pydantic.Tag('InputReportReasonPornography')],
        typing.Annotated[types.InputReportReasonSpam, pydantic.Tag('InputReportReasonSpam')],
        typing.Annotated[types.InputReportReasonViolence, pydantic.Tag('InputReportReasonViolence')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaGiveawayResults(BaseModel):
    """
    types.MessageMediaGiveawayResults
    ID: 0xc6991068
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaGiveawayResults', 'MessageMediaGiveawayResults'] = pydantic.Field(
        'types.MessageMediaGiveawayResults',
        alias='_'
    )

    channel_id: int
    launch_msg_id: int
    winners_count: int
    unclaimed_count: int
    winners: list[int]
    months: int
    until_date: Datetime
    only_new_subscribers: typing.Optional[bool] = None
    refunded: typing.Optional[bool] = None
    additional_peers_count: typing.Optional[int] = None
    prize_description: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PeerColorOption(BaseModel):
    """
    types.help.PeerColorOption
    ID: 0xadec6ebe
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.PeerColorOption', 'PeerColorOption'] = pydantic.Field(
        'types.help.PeerColorOption',
        alias='_'
    )

    color_id: int
    hidden: typing.Optional[bool] = None
    colors: typing.Optional["base.help.PeerColorSet"] = None
    dark_colors: typing.Optional["base.help.PeerColorSet"] = None
    channel_min_level: typing.Optional[int] = None
    group_min_level: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaStory(BaseModel):
    """
    types.MessageMediaStory
    ID: 0x68cb6283
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaStory', 'MessageMediaStory'] = pydantic.Field(
        'types.MessageMediaStory',
        alias='_'
    )

    peer: "base.Peer"
    id: int
    via_mention: typing.Optional[bool] = None
    story: typing.Optional["base.StoryItem"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class CodeSettings(BaseModel):
    """
    types.CodeSettings
    ID: 0xad253d78
    Layer: 181
    """
    QUALNAME: typing.Literal['types.CodeSettings', 'CodeSettings'] = pydantic.Field(
        'types.CodeSettings',
        alias='_'
    )

    allow_flashcall: typing.Optional[bool] = None
    current_number: typing.Optional[bool] = None
    allow_app_hash: typing.Optional[bool] = None
    allow_missed_call: typing.Optional[bool] = None
    allow_firebase: typing.Optional[bool] = None
    unknown_number: typing.Optional[bool] = None
    logout_tokens: typing.Optional[list[Bytes]] = None
    token: typing.Optional[str] = None
    app_sandbox: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# NotifyPeer - Layer 181
NotifyPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.NotifyBroadcasts, pydantic.Tag('NotifyBroadcasts')],
        typing.Annotated[types.NotifyChats, pydantic.Tag('NotifyChats')],
        typing.Annotated[types.NotifyForumTopic, pydantic.Tag('NotifyForumTopic')],
        typing.Annotated[types.NotifyPeer, pydantic.Tag('NotifyPeer')],
        typing.Annotated[types.NotifyUsers, pydantic.Tag('NotifyUsers')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ReorderUsernames(BaseModel):
    """
    functions.bots.ReorderUsernames
    ID: 0x9709b1c2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.bots.ReorderUsernames', 'ReorderUsernames'] = pydantic.Field(
        'functions.bots.ReorderUsernames',
        alias='_'
    )

    bot: "base.InputUser"
    order: list[str]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AttachMenuBots(BaseModel):
    """
    types.AttachMenuBots
    ID: 0x3c4301c0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AttachMenuBots', 'AttachMenuBots'] = pydantic.Field(
        'types.AttachMenuBots',
        alias='_'
    )

    hash: int
    bots: list["base.AttachMenuBot"]
    users: list["base.User"]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecureValueType - Layer 181
SecureValueType = typing.Annotated[
    typing.Union[
        typing.Annotated[types.SecureValueTypeAddress, pydantic.Tag('SecureValueTypeAddress')],
        typing.Annotated[types.SecureValueTypeBankStatement, pydantic.Tag('SecureValueTypeBankStatement')],
        typing.Annotated[types.SecureValueTypeDriverLicense, pydantic.Tag('SecureValueTypeDriverLicense')],
        typing.Annotated[types.SecureValueTypeEmail, pydantic.Tag('SecureValueTypeEmail')],
        typing.Annotated[types.SecureValueTypeIdentityCard, pydantic.Tag('SecureValueTypeIdentityCard')],
        typing.Annotated[types.SecureValueTypeInternalPassport, pydantic.Tag('SecureValueTypeInternalPassport')],
        typing.Annotated[types.SecureValueTypePassport, pydantic.Tag('SecureValueTypePassport')],
        typing.Annotated[types.SecureValueTypePassportRegistration, pydantic.Tag('SecureValueTypePassportRegistration')],
        typing.Annotated[types.SecureValueTypePersonalDetails, pydantic.Tag('SecureValueTypePersonalDetails')],
        typing.Annotated[types.SecureValueTypePhone, pydantic.Tag('SecureValueTypePhone')],
        typing.Annotated[types.SecureValueTypeRentalAgreement, pydantic.Tag('SecureValueTypeRentalAgreement')],
        typing.Annotated[types.SecureValueTypeTemporaryRegistration, pydantic.Tag('SecureValueTypeTemporaryRegistration')],
        typing.Annotated[types.SecureValueTypeUtilityBill, pydantic.Tag('SecureValueTypeUtilityBill')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# photos.Photos - Layer 181
Photos = typing.Annotated[
    typing.Union[
        typing.Annotated[types.photos.Photos, pydantic.Tag('photos.Photos')],
        typing.Annotated[types.photos.PhotosSlice, pydantic.Tag('photos.PhotosSlice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# SecureValueError - Layer 181
SecureValueError = typing.Annotated[
    typing.Union[
        typing.Annotated[types.SecureValueError, pydantic.Tag('SecureValueError')],
        typing.Annotated[types.SecureValueErrorData, pydantic.Tag('SecureValueErrorData')],
        typing.Annotated[types.SecureValueErrorFile, pydantic.Tag('SecureValueErrorFile')],
        typing.Annotated[types.SecureValueErrorFiles, pydantic.Tag('SecureValueErrorFiles')],
        typing.Annotated[types.SecureValueErrorFrontSide, pydantic.Tag('SecureValueErrorFrontSide')],
        typing.Annotated[types.SecureValueErrorReverseSide, pydantic.Tag('SecureValueErrorReverseSide')],
        typing.Annotated[types.SecureValueErrorSelfie, pydantic.Tag('SecureValueErrorSelfie')],
        typing.Annotated[types.SecureValueErrorTranslationFile, pydantic.Tag('SecureValueErrorTranslationFile')],
        typing.Annotated[types.SecureValueErrorTranslationFiles, pydantic.Tag('SecureValueErrorTranslationFiles')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPeer - Layer 181
InputPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputPeerChannel, pydantic.Tag('InputPeerChannel')],
        typing.Annotated[types.InputPeerChannelFromMessage, pydantic.Tag('InputPeerChannelFromMessage')],
        typing.Annotated[types.InputPeerChat, pydantic.Tag('InputPeerChat')],
        typing.Annotated[types.InputPeerEmpty, pydantic.Tag('InputPeerEmpty')],
        typing.Annotated[types.InputPeerSelf, pydantic.Tag('InputPeerSelf')],
        typing.Annotated[types.InputPeerUser, pydantic.Tag('InputPeerUser')],
        typing.Annotated[types.InputPeerUserFromMessage, pydantic.Tag('InputPeerUserFromMessage')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SaveAutoSaveSettings(BaseModel):
    """
    functions.account.SaveAutoSaveSettings
    ID: 0xd69b8361
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.SaveAutoSaveSettings', 'SaveAutoSaveSettings'] = pydantic.Field(
        'functions.account.SaveAutoSaveSettings',
        alias='_'
    )

    settings: "base.AutoSaveSettings"
    users: typing.Optional[bool] = None
    chats: typing.Optional[bool] = None
    broadcasts: typing.Optional[bool] = None
    peer: typing.Optional["base.InputPeer"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputPhotoLegacyFileLocation(BaseModel):
    """
    types.InputPhotoLegacyFileLocation
    ID: 0xd83466f3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputPhotoLegacyFileLocation', 'InputPhotoLegacyFileLocation'] = pydantic.Field(
        'types.InputPhotoLegacyFileLocation',
        alias='_'
    )

    id: int
    access_hash: int
    file_reference: Bytes
    volume_id: int
    local_id: int
    secret: int



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputGeoPoint - Layer 181
InputGeoPoint = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputGeoPoint, pydantic.Tag('InputGeoPoint')],
        typing.Annotated[types.InputGeoPointEmpty, pydantic.Tag('InputGeoPointEmpty')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineMessageMediaGeo(BaseModel):
    """
    types.InputBotInlineMessageMediaGeo
    ID: 0x96929a85
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineMessageMediaGeo', 'InputBotInlineMessageMediaGeo'] = pydantic.Field(
        'types.InputBotInlineMessageMediaGeo',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"
    heading: typing.Optional[int] = None
    period: typing.Optional[int] = None
    proximity_notification_radius: typing.Optional[int] = None
    reply_markup: typing.Optional["base.ReplyMarkup"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PaymentForm(BaseModel):
    """
    types.payments.PaymentForm
    ID: 0xa0058751
    Layer: 181
    """
    QUALNAME: typing.Literal['types.payments.PaymentForm', 'PaymentForm'] = pydantic.Field(
        'types.payments.PaymentForm',
        alias='_'
    )

    form_id: int
    bot_id: int
    title: str
    description: str
    invoice: "base.Invoice"
    provider_id: int
    url: str
    users: list["base.User"]
    can_save_credentials: typing.Optional[bool] = None
    password_missing: typing.Optional[bool] = None
    photo: typing.Optional["base.WebDocument"] = None
    native_provider: typing.Optional[str] = None
    native_params: typing.Optional["base.DataJSON"] = None
    additional_methods: typing.Optional[list["base.PaymentFormMethod"]] = None
    saved_info: typing.Optional["base.PaymentRequestedInfo"] = None
    saved_credentials: typing.Optional[list["base.PaymentSavedCredentials"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputPrivacyKey - Layer 181
InputPrivacyKey = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputPrivacyKeyAbout, pydantic.Tag('InputPrivacyKeyAbout')],
        typing.Annotated[types.InputPrivacyKeyAddedByPhone, pydantic.Tag('InputPrivacyKeyAddedByPhone')],
        typing.Annotated[types.InputPrivacyKeyBirthday, pydantic.Tag('InputPrivacyKeyBirthday')],
        typing.Annotated[types.InputPrivacyKeyChatInvite, pydantic.Tag('InputPrivacyKeyChatInvite')],
        typing.Annotated[types.InputPrivacyKeyForwards, pydantic.Tag('InputPrivacyKeyForwards')],
        typing.Annotated[types.InputPrivacyKeyPhoneCall, pydantic.Tag('InputPrivacyKeyPhoneCall')],
        typing.Annotated[types.InputPrivacyKeyPhoneNumber, pydantic.Tag('InputPrivacyKeyPhoneNumber')],
        typing.Annotated[types.InputPrivacyKeyPhoneP2P, pydantic.Tag('InputPrivacyKeyPhoneP2P')],
        typing.Annotated[types.InputPrivacyKeyProfilePhoto, pydantic.Tag('InputPrivacyKeyProfilePhoto')],
        typing.Annotated[types.InputPrivacyKeyStatusTimestamp, pydantic.Tag('InputPrivacyKeyStatusTimestamp')],
        typing.Annotated[types.InputPrivacyKeyVoiceMessages, pydantic.Tag('InputPrivacyKeyVoiceMessages')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.Dialogs - Layer 181
Dialogs = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.Dialogs, pydantic.Tag('messages.Dialogs')],
        typing.Annotated[types.messages.DialogsNotModified, pydantic.Tag('messages.DialogsNotModified')],
        typing.Annotated[types.messages.DialogsSlice, pydantic.Tag('messages.DialogsSlice')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputBotInlineResult - Layer 181
InputBotInlineResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputBotInlineResult, pydantic.Tag('InputBotInlineResult')],
        typing.Annotated[types.InputBotInlineResultDocument, pydantic.Tag('InputBotInlineResultDocument')],
        typing.Annotated[types.InputBotInlineResultGame, pydantic.Tag('InputBotInlineResultGame')],
        typing.Annotated[types.InputBotInlineResultPhoto, pydantic.Tag('InputBotInlineResultPhoto')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneCallDiscarded(BaseModel):
    """
    types.PhoneCallDiscarded
    ID: 0x50ca4de1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneCallDiscarded', 'PhoneCallDiscarded'] = pydantic.Field(
        'types.PhoneCallDiscarded',
        alias='_'
    )

    id: int
    need_rating: typing.Optional[bool] = None
    need_debug: typing.Optional[bool] = None
    video: typing.Optional[bool] = None
    reason: typing.Optional["base.PhoneCallDiscardReason"] = None
    duration: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Updates - Layer 181
Updates = typing.Annotated[
    typing.Union[
        typing.Annotated[types.UpdateShort, pydantic.Tag('UpdateShort')],
        typing.Annotated[types.UpdateShortChatMessage, pydantic.Tag('UpdateShortChatMessage')],
        typing.Annotated[types.UpdateShortMessage, pydantic.Tag('UpdateShortMessage')],
        typing.Annotated[types.UpdateShortSentMessage, pydantic.Tag('UpdateShortSentMessage')],
        typing.Annotated[types.Updates, pydantic.Tag('Updates')],
        typing.Annotated[types.UpdatesCombined, pydantic.Tag('UpdatesCombined')],
        typing.Annotated[types.UpdatesTooLong, pydantic.Tag('UpdatesTooLong')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdatesCombined(BaseModel):
    """
    types.UpdatesCombined
    ID: 0x725b04c3
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdatesCombined', 'UpdatesCombined'] = pydantic.Field(
        'types.UpdatesCombined',
        alias='_'
    )

    updates: list["base.Update"]
    users: list["base.User"]
    chats: list["base.Chat"]
    date: Datetime
    seq_start: int
    seq: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GroupCall(BaseModel):
    """
    types.phone.GroupCall
    ID: 0x9e727aad
    Layer: 181
    """
    QUALNAME: typing.Literal['types.phone.GroupCall', 'GroupCall'] = pydantic.Field(
        'types.phone.GroupCall',
        alias='_'
    )

    call: "base.GroupCall"
    participants: list["base.GroupCallParticipant"]
    participants_next_offset: str
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ImportLoginToken(BaseModel):
    """
    functions.auth.ImportLoginToken
    ID: 0x95ac5ce4
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.ImportLoginToken', 'ImportLoginToken'] = pydantic.Field(
        'functions.auth.ImportLoginToken',
        alias='_'
    )

    token: Bytes



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputGeoPoint(BaseModel):
    """
    types.InputGeoPoint
    ID: 0x48222faf
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputGeoPoint', 'InputGeoPoint'] = pydantic.Field(
        'types.InputGeoPoint',
        alias='_'
    )

    lat: float
    long: float
    accuracy_radius: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BroadcastRevenueTransaction - Layer 181
BroadcastRevenueTransaction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BroadcastRevenueTransactionProceeds, pydantic.Tag('BroadcastRevenueTransactionProceeds')],
        typing.Annotated[types.BroadcastRevenueTransactionRefund, pydantic.Tag('BroadcastRevenueTransactionRefund')],
        typing.Annotated[types.BroadcastRevenueTransactionWithdrawal, pydantic.Tag('BroadcastRevenueTransactionWithdrawal')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class WebPage(BaseModel):
    """
    types.WebPage
    ID: 0xe89c45b2
    Layer: 181
    """
    QUALNAME: typing.Literal['types.WebPage', 'WebPage'] = pydantic.Field(
        'types.WebPage',
        alias='_'
    )

    id: int
    url: str
    display_url: str
    hash: int
    has_large_media: typing.Optional[bool] = None
    type: typing.Optional[str] = None
    site_name: typing.Optional[str] = None
    title: typing.Optional[str] = None
    description: typing.Optional[str] = None
    photo: typing.Optional["base.Photo"] = None
    embed_url: typing.Optional[str] = None
    embed_type: typing.Optional[str] = None
    embed_width: typing.Optional[int] = None
    embed_height: typing.Optional[int] = None
    duration: typing.Optional[int] = None
    author: typing.Optional[str] = None
    document: typing.Optional["base.Document"] = None
    cached_page: typing.Optional["base.Page"] = None
    attributes: typing.Optional[list["base.WebPageAttribute"]] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# help.AppConfig - Layer 181
AppConfig = typing.Annotated[
    typing.Union[
        typing.Annotated[types.help.AppConfig, pydantic.Tag('help.AppConfig')],
        typing.Annotated[types.help.AppConfigNotModified, pydantic.Tag('help.AppConfigNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Message(BaseModel):
    """
    types.Message
    ID: 0x94345242
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Message', 'Message'] = pydantic.Field(
        'types.Message',
        alias='_'
    )

    id: int
    peer_id: "base.Peer"
    date: Datetime
    message: str
    out: typing.Optional[bool] = None
    mentioned: typing.Optional[bool] = None
    media_unread: typing.Optional[bool] = None
    silent: typing.Optional[bool] = None
    post: typing.Optional[bool] = None
    from_scheduled: typing.Optional[bool] = None
    legacy: typing.Optional[bool] = None
    edit_hide: typing.Optional[bool] = None
    pinned: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    invert_media: typing.Optional[bool] = None
    offline: typing.Optional[bool] = None
    from_id: typing.Optional["base.Peer"] = None
    from_boosts_applied: typing.Optional[int] = None
    saved_peer_id: typing.Optional["base.Peer"] = None
    fwd_from: typing.Optional["base.MessageFwdHeader"] = None
    via_bot_id: typing.Optional[int] = None
    via_business_bot_id: typing.Optional[int] = None
    reply_to: typing.Optional["base.MessageReplyHeader"] = None
    media: typing.Optional["base.MessageMedia"] = None
    reply_markup: typing.Optional["base.ReplyMarkup"] = None
    entities: typing.Optional[list["base.MessageEntity"]] = None
    views: typing.Optional[int] = None
    forwards: typing.Optional[int] = None
    replies: typing.Optional["base.MessageReplies"] = None
    edit_date: typing.Optional[Datetime] = None
    post_author: typing.Optional[str] = None
    grouped_id: typing.Optional[int] = None
    reactions: typing.Optional["base.MessageReactions"] = None
    restriction_reason: typing.Optional[list["base.RestrictionReason"]] = None
    ttl_period: typing.Optional[int] = None
    quick_reply_shortcut_id: typing.Optional[int] = None
    effect: typing.Optional[int] = None
    factcheck: typing.Optional["base.FactCheck"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# WebPage - Layer 181
WebPage = typing.Annotated[
    typing.Union[
        typing.Annotated[types.WebPage, pydantic.Tag('WebPage')],
        typing.Annotated[types.WebPageEmpty, pydantic.Tag('WebPageEmpty')],
        typing.Annotated[types.WebPageNotModified, pydantic.Tag('WebPageNotModified')],
        typing.Annotated[types.WebPagePending, pydantic.Tag('WebPagePending')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaUploadedDocument(BaseModel):
    """
    types.InputMediaUploadedDocument
    ID: 0x5b38c6c1
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaUploadedDocument', 'InputMediaUploadedDocument'] = pydantic.Field(
        'types.InputMediaUploadedDocument',
        alias='_'
    )

    file: "base.InputFile"
    mime_type: str
    attributes: list["base.DocumentAttribute"]
    nosound_video: typing.Optional[bool] = None
    force_file: typing.Optional[bool] = None
    spoiler: typing.Optional[bool] = None
    thumb: typing.Optional["base.InputFile"] = None
    stickers: typing.Optional[list["base.InputDocument"]] = None
    ttl_seconds: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DeleteHistory(BaseModel):
    """
    functions.messages.DeleteHistory
    ID: 0xb08f922a
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.DeleteHistory', 'DeleteHistory'] = pydantic.Field(
        'functions.messages.DeleteHistory',
        alias='_'
    )

    peer: "base.InputPeer"
    max_id: int
    just_clear: typing.Optional[bool] = None
    revoke: typing.Optional[bool] = None
    min_date: typing.Optional[Datetime] = None
    max_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# TopPeerCategory - Layer 181
TopPeerCategory = typing.Annotated[
    typing.Union[
        typing.Annotated[types.TopPeerCategoryBotsInline, pydantic.Tag('TopPeerCategoryBotsInline')],
        typing.Annotated[types.TopPeerCategoryBotsPM, pydantic.Tag('TopPeerCategoryBotsPM')],
        typing.Annotated[types.TopPeerCategoryChannels, pydantic.Tag('TopPeerCategoryChannels')],
        typing.Annotated[types.TopPeerCategoryCorrespondents, pydantic.Tag('TopPeerCategoryCorrespondents')],
        typing.Annotated[types.TopPeerCategoryForwardChats, pydantic.Tag('TopPeerCategoryForwardChats')],
        typing.Annotated[types.TopPeerCategoryForwardUsers, pydantic.Tag('TopPeerCategoryForwardUsers')],
        typing.Annotated[types.TopPeerCategoryGroups, pydantic.Tag('TopPeerCategoryGroups')],
        typing.Annotated[types.TopPeerCategoryPhoneCalls, pydantic.Tag('TopPeerCategoryPhoneCalls')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# BotMenuButton - Layer 181
BotMenuButton = typing.Annotated[
    typing.Union[
        typing.Annotated[types.BotMenuButton, pydantic.Tag('BotMenuButton')],
        typing.Annotated[types.BotMenuButtonCommands, pydantic.Tag('BotMenuButtonCommands')],
        typing.Annotated[types.BotMenuButtonDefault, pydantic.Tag('BotMenuButtonDefault')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateSentStoryReaction(BaseModel):
    """
    types.UpdateSentStoryReaction
    ID: 0x7d627683
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateSentStoryReaction', 'UpdateSentStoryReaction'] = pydantic.Field(
        'types.UpdateSentStoryReaction',
        alias='_'
    )

    peer: "base.Peer"
    story_id: int
    reaction: "base.Reaction"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetBoostsList(BaseModel):
    """
    functions.premium.GetBoostsList
    ID: 0x60f67660
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.premium.GetBoostsList', 'GetBoostsList'] = pydantic.Field(
        'functions.premium.GetBoostsList',
        alias='_'
    )

    peer: "base.InputPeer"
    offset: str
    limit: int
    gifts: typing.Optional[bool] = None



from .get_payment_form import GetPaymentForm
from .get_payment_receipt import GetPaymentReceipt
from .validate_requested_info import ValidateRequestedInfo
from .send_payment_form import SendPaymentForm
from .get_saved_info import GetSavedInfo
from .clear_saved_info import ClearSavedInfo
from .get_bank_card_data import GetBankCardData
from .export_invoice import ExportInvoice
from .assign_app_store_transaction import AssignAppStoreTransaction
from .assign_play_market_transaction import AssignPlayMarketTransaction
from .can_purchase_premium import CanPurchasePremium
from .get_premium_gift_code_options import GetPremiumGiftCodeOptions
from .check_gift_code import CheckGiftCode
from .apply_gift_code import ApplyGiftCode
from .get_giveaway_info import GetGiveawayInfo
from .launch_prepaid_giveaway import LaunchPrepaidGiveaway
from .get_stars_topup_options import GetStarsTopupOptions
from .get_stars_status import GetStarsStatus
from .get_stars_transactions import GetStarsTransactions
from .send_stars_form import SendStarsForm
from .refund_stars_charge import RefundStarsCharge



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class EmojiKeywordsDifference(BaseModel):
    """
    types.EmojiKeywordsDifference
    ID: 0x5cc761bd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.EmojiKeywordsDifference', 'EmojiKeywordsDifference'] = pydantic.Field(
        'types.EmojiKeywordsDifference',
        alias='_'
    )

    lang_code: str
    from_version: int
    version: int
    keywords: list["base.EmojiKeyword"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Document(BaseModel):
    """
    types.Document
    ID: 0x8fd4c4d8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Document', 'Document'] = pydantic.Field(
        'types.Document',
        alias='_'
    )

    id: int
    access_hash: int
    file_reference: Bytes
    date: Datetime
    mime_type: str
    size: int
    dc_id: int
    attributes: list["base.DocumentAttribute"]
    thumbs: typing.Optional[list["base.PhotoSize"]] = None
    video_thumbs: typing.Optional[list["base.VideoSize"]] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputGameShortName(BaseModel):
    """
    types.InputGameShortName
    ID: 0xc331e80a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputGameShortName', 'InputGameShortName'] = pydantic.Field(
        'types.InputGameShortName',
        alias='_'
    )

    bot_id: "base.InputUser"
    short_name: str



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# Dialog - Layer 181
Dialog = typing.Annotated[
    typing.Union[
        typing.Annotated[types.Dialog, pydantic.Tag('Dialog')],
        typing.Annotated[types.DialogFolder, pydantic.Tag('DialogFolder')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChannelAdminLogEventActionChangeLinkedChat(BaseModel):
    """
    types.ChannelAdminLogEventActionChangeLinkedChat
    ID: 0x50c7ac8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChannelAdminLogEventActionChangeLinkedChat', 'ChannelAdminLogEventActionChangeLinkedChat'] = pydantic.Field(
        'types.ChannelAdminLogEventActionChangeLinkedChat',
        alias='_'
    )

    prev_value: int
    new_value: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputGroupCallStream(BaseModel):
    """
    types.InputGroupCallStream
    ID: 0x598a92a
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputGroupCallStream', 'InputGroupCallStream'] = pydantic.Field(
        'types.InputGroupCallStream',
        alias='_'
    )

    call: "base.InputGroupCall"
    time_ms: int
    scale: int
    video_channel: typing.Optional[int] = None
    video_quality: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaPhoto(BaseModel):
    """
    types.InputMediaPhoto
    ID: 0xb3ba0635
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaPhoto', 'InputMediaPhoto'] = pydantic.Field(
        'types.InputMediaPhoto',
        alias='_'
    )

    id: "base.InputPhoto"
    spoiler: typing.Optional[bool] = None
    ttl_seconds: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class BroadcastRevenueTransactionWithdrawal(BaseModel):
    """
    types.BroadcastRevenueTransactionWithdrawal
    ID: 0x5a590978
    Layer: 181
    """
    QUALNAME: typing.Literal['types.BroadcastRevenueTransactionWithdrawal', 'BroadcastRevenueTransactionWithdrawal'] = pydantic.Field(
        'types.BroadcastRevenueTransactionWithdrawal',
        alias='_'
    )

    amount: int
    date: Datetime
    provider: str
    pending: typing.Optional[bool] = None
    failed: typing.Optional[bool] = None
    transaction_date: typing.Optional[Datetime] = None
    transaction_url: typing.Optional[str] = None



from .state import State
from .difference_empty import DifferenceEmpty
from .difference import Difference
from .difference_slice import DifferenceSlice
from .difference_too_long import DifferenceTooLong
from .channel_difference_empty import ChannelDifferenceEmpty
from .channel_difference_too_long import ChannelDifferenceTooLong
from .channel_difference import ChannelDifference



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaGiveaway(BaseModel):
    """
    types.MessageMediaGiveaway
    ID: 0xdaad85b0
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaGiveaway', 'MessageMediaGiveaway'] = pydantic.Field(
        'types.MessageMediaGiveaway',
        alias='_'
    )

    channels: list[int]
    quantity: int
    months: int
    until_date: Datetime
    only_new_subscribers: typing.Optional[bool] = None
    winners_are_visible: typing.Optional[bool] = None
    countries_iso2: typing.Optional[list[str]] = None
    prize_description: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UserFull(BaseModel):
    """
    types.UserFull
    ID: 0xcc997720
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UserFull', 'UserFull'] = pydantic.Field(
        'types.UserFull',
        alias='_'
    )

    id: int
    settings: "base.PeerSettings"
    notify_settings: "base.PeerNotifySettings"
    common_chats_count: int
    blocked: typing.Optional[bool] = None
    phone_calls_available: typing.Optional[bool] = None
    phone_calls_private: typing.Optional[bool] = None
    can_pin_message: typing.Optional[bool] = None
    has_scheduled: typing.Optional[bool] = None
    video_calls_available: typing.Optional[bool] = None
    voice_messages_forbidden: typing.Optional[bool] = None
    translations_disabled: typing.Optional[bool] = None
    stories_pinned_available: typing.Optional[bool] = None
    blocked_my_stories_from: typing.Optional[bool] = None
    wallpaper_overridden: typing.Optional[bool] = None
    contact_require_premium: typing.Optional[bool] = None
    read_dates_private: typing.Optional[bool] = None
    sponsored_enabled: typing.Optional[bool] = None
    about: typing.Optional[str] = None
    personal_photo: typing.Optional["base.Photo"] = None
    profile_photo: typing.Optional["base.Photo"] = None
    fallback_photo: typing.Optional["base.Photo"] = None
    bot_info: typing.Optional["base.BotInfo"] = None
    pinned_msg_id: typing.Optional[int] = None
    folder_id: typing.Optional[int] = None
    ttl_period: typing.Optional[int] = None
    theme_emoticon: typing.Optional[str] = None
    private_forward_name: typing.Optional[str] = None
    bot_group_admin_rights: typing.Optional["base.ChatAdminRights"] = None
    bot_broadcast_admin_rights: typing.Optional["base.ChatAdminRights"] = None
    premium_gifts: typing.Optional[list["base.PremiumGiftOption"]] = None
    wallpaper: typing.Optional["base.WallPaper"] = None
    stories: typing.Optional["base.PeerStories"] = None
    business_work_hours: typing.Optional["base.BusinessWorkHours"] = None
    business_location: typing.Optional["base.BusinessLocation"] = None
    business_greeting_message: typing.Optional["base.BusinessGreetingMessage"] = None
    business_away_message: typing.Optional["base.BusinessAwayMessage"] = None
    business_intro: typing.Optional["base.BusinessIntro"] = None
    birthday: typing.Optional["base.Birthday"] = None
    personal_channel_id: typing.Optional[int] = None
    personal_channel_message: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ReplyMarkup - Layer 181
ReplyMarkup = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ReplyInlineMarkup, pydantic.Tag('ReplyInlineMarkup')],
        typing.Annotated[types.ReplyKeyboardForceReply, pydantic.Tag('ReplyKeyboardForceReply')],
        typing.Annotated[types.ReplyKeyboardHide, pydantic.Tag('ReplyKeyboardHide')],
        typing.Annotated[types.ReplyKeyboardMarkup, pydantic.Tag('ReplyKeyboardMarkup')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ChatParticipant - Layer 181
ChatParticipant = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChatParticipant, pydantic.Tag('ChatParticipant')],
        typing.Annotated[types.ChatParticipantAdmin, pydantic.Tag('ChatParticipantAdmin')],
        typing.Annotated[types.ChatParticipantCreator, pydantic.Tag('ChatParticipantCreator')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class FactCheck(BaseModel):
    """
    types.FactCheck
    ID: 0xb89bfccf
    Layer: 181
    """
    QUALNAME: typing.Literal['types.FactCheck', 'FactCheck'] = pydantic.Field(
        'types.FactCheck',
        alias='_'
    )

    hash: int
    need_check: typing.Optional[bool] = None
    country: typing.Optional[str] = None
    text: typing.Optional["base.TextWithEntities"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendMessageGamePlayAction(BaseModel):
    """
    types.SendMessageGamePlayAction
    ID: 0xdd6a8f48
    Layer: 181
    """
    QUALNAME: typing.Literal['types.SendMessageGamePlayAction', 'SendMessageGamePlayAction'] = pydantic.Field(
        'types.SendMessageGamePlayAction',
        alias='_'
    )




from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetPollVotes(BaseModel):
    """
    functions.messages.GetPollVotes
    ID: 0xb86e380e
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetPollVotes', 'GetPollVotes'] = pydantic.Field(
        'functions.messages.GetPollVotes',
        alias='_'
    )

    peer: "base.InputPeer"
    id: int
    limit: int
    option: typing.Optional[Bytes] = None
    offset: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ChatInviteExported(BaseModel):
    """
    types.ChatInviteExported
    ID: 0xab4a819
    Layer: 181
    """
    QUALNAME: typing.Literal['types.ChatInviteExported', 'ChatInviteExported'] = pydantic.Field(
        'types.ChatInviteExported',
        alias='_'
    )

    link: str
    admin_id: int
    date: Datetime
    revoked: typing.Optional[bool] = None
    permanent: typing.Optional[bool] = None
    request_needed: typing.Optional[bool] = None
    start_date: typing.Optional[Datetime] = None
    expire_date: typing.Optional[Datetime] = None
    usage_limit: typing.Optional[int] = None
    usage: typing.Optional[int] = None
    requested: typing.Optional[int] = None
    title: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageMediaDocument(BaseModel):
    """
    types.MessageMediaDocument
    ID: 0x4cf4d72d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageMediaDocument', 'MessageMediaDocument'] = pydantic.Field(
        'types.MessageMediaDocument',
        alias='_'
    )

    nopremium: typing.Optional[bool] = None
    spoiler: typing.Optional[bool] = None
    video: typing.Optional[bool] = None
    round: typing.Optional[bool] = None
    voice: typing.Optional[bool] = None
    document: typing.Optional["base.Document"] = None
    alt_document: typing.Optional["base.Document"] = None
    ttl_seconds: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# PrivacyRule - Layer 181
PrivacyRule = typing.Annotated[
    typing.Union[
        typing.Annotated[types.PrivacyValueAllowAll, pydantic.Tag('PrivacyValueAllowAll')],
        typing.Annotated[types.PrivacyValueAllowChatParticipants, pydantic.Tag('PrivacyValueAllowChatParticipants')],
        typing.Annotated[types.PrivacyValueAllowCloseFriends, pydantic.Tag('PrivacyValueAllowCloseFriends')],
        typing.Annotated[types.PrivacyValueAllowContacts, pydantic.Tag('PrivacyValueAllowContacts')],
        typing.Annotated[types.PrivacyValueAllowPremium, pydantic.Tag('PrivacyValueAllowPremium')],
        typing.Annotated[types.PrivacyValueAllowUsers, pydantic.Tag('PrivacyValueAllowUsers')],
        typing.Annotated[types.PrivacyValueDisallowAll, pydantic.Tag('PrivacyValueDisallowAll')],
        typing.Annotated[types.PrivacyValueDisallowChatParticipants, pydantic.Tag('PrivacyValueDisallowChatParticipants')],
        typing.Annotated[types.PrivacyValueDisallowContacts, pydantic.Tag('PrivacyValueDisallowContacts')],
        typing.Annotated[types.PrivacyValueDisallowUsers, pydantic.Tag('PrivacyValueDisallowUsers')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UpdateServiceNotification(BaseModel):
    """
    types.UpdateServiceNotification
    ID: 0xebe46819
    Layer: 181
    """
    QUALNAME: typing.Literal['types.UpdateServiceNotification', 'UpdateServiceNotification'] = pydantic.Field(
        'types.UpdateServiceNotification',
        alias='_'
    )

    type: str
    message: str
    media: "base.MessageMedia"
    entities: list["base.MessageEntity"]
    popup: typing.Optional[bool] = None
    invert_media: typing.Optional[bool] = None
    inbox_date: typing.Optional[Datetime] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PremiumPromo(BaseModel):
    """
    types.help.PremiumPromo
    ID: 0x5334759c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.PremiumPromo', 'PremiumPromo'] = pydantic.Field(
        'types.help.PremiumPromo',
        alias='_'
    )

    status_text: str
    status_entities: list["base.MessageEntity"]
    video_sections: list[str]
    videos: list["base.Document"]
    period_options: list["base.PremiumSubscriptionOption"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneCallRequested(BaseModel):
    """
    types.PhoneCallRequested
    ID: 0x14b0ed0c
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneCallRequested', 'PhoneCallRequested'] = pydantic.Field(
        'types.PhoneCallRequested',
        alias='_'
    )

    id: int
    access_hash: int
    date: Datetime
    admin_id: int
    participant_id: int
    g_a_hash: Bytes
    protocol: "base.PhoneCallProtocol"
    video: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageService(BaseModel):
    """
    types.MessageService
    ID: 0x2b085862
    Layer: 181
    """
    QUALNAME: typing.Literal['types.MessageService', 'MessageService'] = pydantic.Field(
        'types.MessageService',
        alias='_'
    )

    id: int
    peer_id: "base.Peer"
    date: Datetime
    action: "base.MessageAction"
    out: typing.Optional[bool] = None
    mentioned: typing.Optional[bool] = None
    media_unread: typing.Optional[bool] = None
    silent: typing.Optional[bool] = None
    post: typing.Optional[bool] = None
    legacy: typing.Optional[bool] = None
    from_id: typing.Optional["base.Peer"] = None
    reply_to: typing.Optional["base.MessageReplyHeader"] = None
    ttl_period: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class AvailableReaction(BaseModel):
    """
    types.AvailableReaction
    ID: 0xc077ec01
    Layer: 181
    """
    QUALNAME: typing.Literal['types.AvailableReaction', 'AvailableReaction'] = pydantic.Field(
        'types.AvailableReaction',
        alias='_'
    )

    reaction: str
    title: str
    static_icon: "base.Document"
    appear_animation: "base.Document"
    select_animation: "base.Document"
    activate_animation: "base.Document"
    effect_animation: "base.Document"
    inactive: typing.Optional[bool] = None
    premium: typing.Optional[bool] = None
    around_animation: typing.Optional["base.Document"] = None
    center_icon: typing.Optional["base.Document"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputInvoice - Layer 181
InputInvoice = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputInvoiceMessage, pydantic.Tag('InputInvoiceMessage')],
        typing.Annotated[types.InputInvoicePremiumGiftCode, pydantic.Tag('InputInvoicePremiumGiftCode')],
        typing.Annotated[types.InputInvoiceSlug, pydantic.Tag('InputInvoiceSlug')],
        typing.Annotated[types.InputInvoiceStars, pydantic.Tag('InputInvoiceStars')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SearchPosts(BaseModel):
    """
    functions.channels.SearchPosts
    ID: 0xd19f987b
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.channels.SearchPosts', 'SearchPosts'] = pydantic.Field(
        'functions.channels.SearchPosts',
        alias='_'
    )

    hashtag: str
    offset_rate: int
    offset_peer: "base.InputPeer"
    offset_id: int
    limit: int



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RecentMeUrls(BaseModel):
    """
    types.help.RecentMeUrls
    ID: 0xe0310d7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.RecentMeUrls', 'RecentMeUrls'] = pydantic.Field(
        'types.help.RecentMeUrls',
        alias='_'
    )

    urls: list["base.RecentMeUrl"]
    chats: list["base.Chat"]
    users: list["base.User"]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Boost(BaseModel):
    """
    types.Boost
    ID: 0x2a1c8c71
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Boost', 'Boost'] = pydantic.Field(
        'types.Boost',
        alias='_'
    )

    id: str
    date: Datetime
    expires: Datetime
    gift: typing.Optional[bool] = None
    giveaway: typing.Optional[bool] = None
    unclaimed: typing.Optional[bool] = None
    user_id: typing.Optional[int] = None
    giveaway_msg_id: typing.Optional[int] = None
    used_gift_slug: typing.Optional[str] = None
    multiplier: typing.Optional[int] = None



from .invoke_after_msg import InvokeAfterMsg
from .invoke_after_msgs import InvokeAfterMsgs
from .init_connection import InitConnection
from .invoke_with_layer import InvokeWithLayer
from .invoke_without_updates import InvokeWithoutUpdates
from .invoke_with_messages_range import InvokeWithMessagesRange
from .invoke_with_takeout import InvokeWithTakeout
from .invoke_with_business_connection import InvokeWithBusinessConnection
from .invoke_with_google_play_integrity import InvokeWithGooglePlayIntegrity
from .invoke_with_apns_secret import InvokeWithApnsSecret
from . import auth, account, users, contacts, messages, updates, photos, upload, help, channels, bots, payments, stickers, phone, langpack, folders, stats, chatlists, stories, premium, smsjobs, fragment


from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class MessageReactionsList(BaseModel):
    """
    types.messages.MessageReactionsList
    ID: 0x31bd492d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.MessageReactionsList', 'MessageReactionsList'] = pydantic.Field(
        'types.messages.MessageReactionsList',
        alias='_'
    )

    count: int
    reactions: list["base.MessagePeerReaction"]
    chats: list["base.Chat"]
    users: list["base.User"]
    next_offset: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetTopPeers(BaseModel):
    """
    functions.contacts.GetTopPeers
    ID: 0x973478b6
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.GetTopPeers', 'GetTopPeers'] = pydantic.Field(
        'functions.contacts.GetTopPeers',
        alias='_'
    )

    offset: int
    limit: int
    hash: int
    correspondents: typing.Optional[bool] = None
    bots_pm: typing.Optional[bool] = None
    bots_inline: typing.Optional[bool] = None
    phone_calls: typing.Optional[bool] = None
    forward_users: typing.Optional[bool] = None
    forward_chats: typing.Optional[bool] = None
    groups: typing.Optional[bool] = None
    channels: typing.Optional[bool] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# stories.AllStories - Layer 181
AllStories = typing.Annotated[
    typing.Union[
        typing.Annotated[types.stories.AllStories, pydantic.Tag('stories.AllStories')],
        typing.Annotated[types.stories.AllStoriesNotModified, pydantic.Tag('stories.AllStoriesNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# ExportedChatInvite - Layer 181
ExportedChatInvite = typing.Annotated[
    typing.Union[
        typing.Annotated[types.ChatInviteExported, pydantic.Tag('ChatInviteExported')],
        typing.Annotated[types.ChatInvitePublicJoinRequests, pydantic.Tag('ChatInvitePublicJoinRequests')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class UploadTheme(BaseModel):
    """
    functions.account.UploadTheme
    ID: 0x1c3db333
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.account.UploadTheme', 'UploadTheme'] = pydantic.Field(
        'functions.account.UploadTheme',
        alias='_'
    )

    file: "base.InputFile"
    file_name: str
    mime_type: str
    thumb: typing.Optional["base.InputFile"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SentEncryptedFile(BaseModel):
    """
    types.messages.SentEncryptedFile
    ID: 0x9493ff32
    Layer: 181
    """
    QUALNAME: typing.Literal['types.messages.SentEncryptedFile', 'SentEncryptedFile'] = pydantic.Field(
        'types.messages.SentEncryptedFile',
        alias='_'
    )

    date: Datetime
    file: "base.EncryptedFile"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RecentMeUrlChatInvite(BaseModel):
    """
    types.RecentMeUrlChatInvite
    ID: 0xeb49081d
    Layer: 181
    """
    QUALNAME: typing.Literal['types.RecentMeUrlChatInvite', 'RecentMeUrlChatInvite'] = pydantic.Field(
        'types.RecentMeUrlChatInvite',
        alias='_'
    )

    url: str
    chat_invite: "base.ChatInvite"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestUrlAuth(BaseModel):
    """
    functions.messages.RequestUrlAuth
    ID: 0x198fb446
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.RequestUrlAuth', 'RequestUrlAuth'] = pydantic.Field(
        'functions.messages.RequestUrlAuth',
        alias='_'
    )

    peer: typing.Optional["base.InputPeer"] = None
    msg_id: typing.Optional[int] = None
    button_id: typing.Optional[int] = None
    url: typing.Optional[str] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputBotInlineMessageMediaContact(BaseModel):
    """
    types.InputBotInlineMessageMediaContact
    ID: 0xa6edbffd
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputBotInlineMessageMediaContact', 'InputBotInlineMessageMediaContact'] = pydantic.Field(
        'types.InputBotInlineMessageMediaContact',
        alias='_'
    )

    phone_number: str
    first_name: str
    last_name: str
    vcard: str
    reply_markup: typing.Optional["base.ReplyMarkup"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class DifferenceSlice(BaseModel):
    """
    types.updates.DifferenceSlice
    ID: 0xa8fb1981
    Layer: 181
    """
    QUALNAME: typing.Literal['types.updates.DifferenceSlice', 'DifferenceSlice'] = pydantic.Field(
        'types.updates.DifferenceSlice',
        alias='_'
    )

    new_messages: list["base.Message"]
    new_encrypted_messages: list["base.EncryptedMessage"]
    other_updates: list["base.Update"]
    chats: list["base.Chat"]
    users: list["base.User"]
    intermediate_state: "base.updates.State"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class LoadAsyncGraph(BaseModel):
    """
    functions.stats.LoadAsyncGraph
    ID: 0x621d5fa0
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stats.LoadAsyncGraph', 'LoadAsyncGraph'] = pydantic.Field(
        'functions.stats.LoadAsyncGraph',
        alias='_'
    )

    token: str
    x: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# UrlAuthResult - Layer 181
UrlAuthResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.UrlAuthResultAccepted, pydantic.Tag('UrlAuthResultAccepted')],
        typing.Annotated[types.UrlAuthResultDefault, pydantic.Tag('UrlAuthResultDefault')],
        typing.Annotated[types.UrlAuthResultRequest, pydantic.Tag('UrlAuthResultRequest')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# MessageAction - Layer 181
MessageAction = typing.Annotated[
    typing.Union[
        typing.Annotated[types.MessageActionBoostApply, pydantic.Tag('MessageActionBoostApply')],
        typing.Annotated[types.MessageActionBotAllowed, pydantic.Tag('MessageActionBotAllowed')],
        typing.Annotated[types.MessageActionChannelCreate, pydantic.Tag('MessageActionChannelCreate')],
        typing.Annotated[types.MessageActionChannelMigrateFrom, pydantic.Tag('MessageActionChannelMigrateFrom')],
        typing.Annotated[types.MessageActionChatAddUser, pydantic.Tag('MessageActionChatAddUser')],
        typing.Annotated[types.MessageActionChatCreate, pydantic.Tag('MessageActionChatCreate')],
        typing.Annotated[types.MessageActionChatDeletePhoto, pydantic.Tag('MessageActionChatDeletePhoto')],
        typing.Annotated[types.MessageActionChatDeleteUser, pydantic.Tag('MessageActionChatDeleteUser')],
        typing.Annotated[types.MessageActionChatEditPhoto, pydantic.Tag('MessageActionChatEditPhoto')],
        typing.Annotated[types.MessageActionChatEditTitle, pydantic.Tag('MessageActionChatEditTitle')],
        typing.Annotated[types.MessageActionChatJoinedByLink, pydantic.Tag('MessageActionChatJoinedByLink')],
        typing.Annotated[types.MessageActionChatJoinedByRequest, pydantic.Tag('MessageActionChatJoinedByRequest')],
        typing.Annotated[types.MessageActionChatMigrateTo, pydantic.Tag('MessageActionChatMigrateTo')],
        typing.Annotated[types.MessageActionContactSignUp, pydantic.Tag('MessageActionContactSignUp')],
        typing.Annotated[types.MessageActionCustomAction, pydantic.Tag('MessageActionCustomAction')],
        typing.Annotated[types.MessageActionEmpty, pydantic.Tag('MessageActionEmpty')],
        typing.Annotated[types.MessageActionGameScore, pydantic.Tag('MessageActionGameScore')],
        typing.Annotated[types.MessageActionGeoProximityReached, pydantic.Tag('MessageActionGeoProximityReached')],
        typing.Annotated[types.MessageActionGiftCode, pydantic.Tag('MessageActionGiftCode')],
        typing.Annotated[types.MessageActionGiftPremium, pydantic.Tag('MessageActionGiftPremium')],
        typing.Annotated[types.MessageActionGiveawayLaunch, pydantic.Tag('MessageActionGiveawayLaunch')],
        typing.Annotated[types.MessageActionGiveawayResults, pydantic.Tag('MessageActionGiveawayResults')],
        typing.Annotated[types.MessageActionGroupCall, pydantic.Tag('MessageActionGroupCall')],
        typing.Annotated[types.MessageActionGroupCallScheduled, pydantic.Tag('MessageActionGroupCallScheduled')],
        typing.Annotated[types.MessageActionHistoryClear, pydantic.Tag('MessageActionHistoryClear')],
        typing.Annotated[types.MessageActionInviteToGroupCall, pydantic.Tag('MessageActionInviteToGroupCall')],
        typing.Annotated[types.MessageActionPaymentSent, pydantic.Tag('MessageActionPaymentSent')],
        typing.Annotated[types.MessageActionPaymentSentMe, pydantic.Tag('MessageActionPaymentSentMe')],
        typing.Annotated[types.MessageActionPhoneCall, pydantic.Tag('MessageActionPhoneCall')],
        typing.Annotated[types.MessageActionPinMessage, pydantic.Tag('MessageActionPinMessage')],
        typing.Annotated[types.MessageActionRequestedPeer, pydantic.Tag('MessageActionRequestedPeer')],
        typing.Annotated[types.MessageActionRequestedPeerSentMe, pydantic.Tag('MessageActionRequestedPeerSentMe')],
        typing.Annotated[types.MessageActionScreenshotTaken, pydantic.Tag('MessageActionScreenshotTaken')],
        typing.Annotated[types.MessageActionSecureValuesSent, pydantic.Tag('MessageActionSecureValuesSent')],
        typing.Annotated[types.MessageActionSecureValuesSentMe, pydantic.Tag('MessageActionSecureValuesSentMe')],
        typing.Annotated[types.MessageActionSetChatTheme, pydantic.Tag('MessageActionSetChatTheme')],
        typing.Annotated[types.MessageActionSetChatWallPaper, pydantic.Tag('MessageActionSetChatWallPaper')],
        typing.Annotated[types.MessageActionSetMessagesTTL, pydantic.Tag('MessageActionSetMessagesTTL')],
        typing.Annotated[types.MessageActionSuggestProfilePhoto, pydantic.Tag('MessageActionSuggestProfilePhoto')],
        typing.Annotated[types.MessageActionTopicCreate, pydantic.Tag('MessageActionTopicCreate')],
        typing.Annotated[types.MessageActionTopicEdit, pydantic.Tag('MessageActionTopicEdit')],
        typing.Annotated[types.MessageActionWebViewDataSent, pydantic.Tag('MessageActionWebViewDataSent')],
        typing.Annotated[types.MessageActionWebViewDataSentMe, pydantic.Tag('MessageActionWebViewDataSentMe')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class RequestCall(BaseModel):
    """
    functions.phone.RequestCall
    ID: 0x42ff96ed
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.RequestCall', 'RequestCall'] = pydantic.Field(
        'functions.phone.RequestCall',
        alias='_'
    )

    user_id: "base.InputUser"
    random_id: int
    g_a_hash: Bytes
    protocol: "base.PhoneCallProtocol"
    video: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InlineBotSwitchPM(BaseModel):
    """
    types.InlineBotSwitchPM
    ID: 0x3c20629f
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InlineBotSwitchPM', 'InlineBotSwitchPM'] = pydantic.Field(
        'types.InlineBotSwitchPM',
        alias='_'
    )

    text: str
    start_param: str



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class Chat(BaseModel):
    """
    types.Chat
    ID: 0x41cbf256
    Layer: 181
    """
    QUALNAME: typing.Literal['types.Chat', 'Chat'] = pydantic.Field(
        'types.Chat',
        alias='_'
    )

    id: int
    title: str
    photo: "base.ChatPhoto"
    participants_count: int
    date: Datetime
    version: int
    creator: typing.Optional[bool] = None
    left: typing.Optional[bool] = None
    deactivated: typing.Optional[bool] = None
    call_active: typing.Optional[bool] = None
    call_not_empty: typing.Optional[bool] = None
    noforwards: typing.Optional[bool] = None
    migrated_to: typing.Optional["base.InputChannel"] = None
    admin_rights: typing.Optional["base.ChatAdminRights"] = None
    default_banned_rights: typing.Optional["base.ChatBannedRights"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class InputMediaGeoPoint(BaseModel):
    """
    types.InputMediaGeoPoint
    ID: 0xf9c44144
    Layer: 181
    """
    QUALNAME: typing.Literal['types.InputMediaGeoPoint', 'InputMediaGeoPoint'] = pydantic.Field(
        'types.InputMediaGeoPoint',
        alias='_'
    )

    geo_point: "base.InputGeoPoint"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GroupCallParticipantVideo(BaseModel):
    """
    types.GroupCallParticipantVideo
    ID: 0x67753ac8
    Layer: 181
    """
    QUALNAME: typing.Literal['types.GroupCallParticipantVideo', 'GroupCallParticipantVideo'] = pydantic.Field(
        'types.GroupCallParticipantVideo',
        alias='_'
    )

    endpoint: str
    source_groups: list["base.GroupCallParticipantVideoSourceGroup"]
    paused: typing.Optional[bool] = None
    audio_source: typing.Optional[int] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# payments.PaymentReceipt - Layer 181
PaymentReceipt = typing.Annotated[
    typing.Union[
        typing.Annotated[types.payments.PaymentReceipt, pydantic.Tag('payments.PaymentReceipt')],
        typing.Annotated[types.payments.PaymentReceiptStars, pydantic.Tag('payments.PaymentReceiptStars')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PageBlockPhoto(BaseModel):
    """
    types.PageBlockPhoto
    ID: 0x1759c560
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PageBlockPhoto', 'PageBlockPhoto'] = pydantic.Field(
        'types.PageBlockPhoto',
        alias='_'
    )

    photo_id: int
    caption: "base.PageCaption"
    url: typing.Optional[str] = None
    webpage_id: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class VideoSizeStickerMarkup(BaseModel):
    """
    types.VideoSizeStickerMarkup
    ID: 0xda082fe
    Layer: 181
    """
    QUALNAME: typing.Literal['types.VideoSizeStickerMarkup', 'VideoSizeStickerMarkup'] = pydantic.Field(
        'types.VideoSizeStickerMarkup',
        alias='_'
    )

    stickerset: "base.InputStickerSet"
    sticker_id: int
    background_colors: list[int]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# channels.SponsoredMessageReportResult - Layer 181
SponsoredMessageReportResult = typing.Annotated[
    typing.Union[
        typing.Annotated[types.channels.SponsoredMessageReportResultAdsHidden, pydantic.Tag('channels.SponsoredMessageReportResultAdsHidden')],
        typing.Annotated[types.channels.SponsoredMessageReportResultChooseOption, pydantic.Tag('channels.SponsoredMessageReportResultChooseOption')],
        typing.Annotated[types.channels.SponsoredMessageReportResultReported, pydantic.Tag('channels.SponsoredMessageReportResultReported')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputWebFileLocation - Layer 181
InputWebFileLocation = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputWebFileAudioAlbumThumbLocation, pydantic.Tag('InputWebFileAudioAlbumThumbLocation')],
        typing.Annotated[types.InputWebFileGeoPointLocation, pydantic.Tag('InputWebFileGeoPointLocation')],
        typing.Annotated[types.InputWebFileLocation, pydantic.Tag('InputWebFileLocation')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# InputNotifyPeer - Layer 181
InputNotifyPeer = typing.Annotated[
    typing.Union[
        typing.Annotated[types.InputNotifyBroadcasts, pydantic.Tag('InputNotifyBroadcasts')],
        typing.Annotated[types.InputNotifyChats, pydantic.Tag('InputNotifyChats')],
        typing.Annotated[types.InputNotifyForumTopic, pydantic.Tag('InputNotifyForumTopic')],
        typing.Annotated[types.InputNotifyPeer, pydantic.Tag('InputNotifyPeer')],
        typing.Annotated[types.InputNotifyUsers, pydantic.Tag('InputNotifyUsers')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# upload.File - Layer 181
File = typing.Annotated[
    typing.Union[
        typing.Annotated[types.upload.File, pydantic.Tag('upload.File')],
        typing.Annotated[types.upload.FileCdnRedirect, pydantic.Tag('upload.FileCdnRedirect')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# messages.QuickReplies - Layer 181
QuickReplies = typing.Annotated[
    typing.Union[
        typing.Annotated[types.messages.QuickReplies, pydantic.Tag('messages.QuickReplies')],
        typing.Annotated[types.messages.QuickRepliesNotModified, pydantic.Tag('messages.QuickRepliesNotModified')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class ExportLoginToken(BaseModel):
    """
    functions.auth.ExportLoginToken
    ID: 0xb7e085fe
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.auth.ExportLoginToken', 'ExportLoginToken'] = pydantic.Field(
        'functions.auth.ExportLoginToken',
        alias='_'
    )

    api_id: int
    api_hash: str
    except_ids: list[int]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class JoinGroupCallPresentation(BaseModel):
    """
    functions.phone.JoinGroupCallPresentation
    ID: 0xcbea6bc4
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.phone.JoinGroupCallPresentation', 'JoinGroupCallPresentation'] = pydantic.Field(
        'functions.phone.JoinGroupCallPresentation',
        alias='_'
    )

    call: "base.InputGroupCall"
    params: "base.DataJSON"



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class PhoneConnection(BaseModel):
    """
    types.PhoneConnection
    ID: 0x9cc123c7
    Layer: 181
    """
    QUALNAME: typing.Literal['types.PhoneConnection', 'PhoneConnection'] = pydantic.Field(
        'types.PhoneConnection',
        alias='_'
    )

    id: int
    ip: str
    ipv6: str
    port: int
    peer_tag: Bytes
    tcp: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetSearchResultsCalendar(BaseModel):
    """
    functions.messages.GetSearchResultsCalendar
    ID: 0x6aa3f6bd
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.messages.GetSearchResultsCalendar', 'GetSearchResultsCalendar'] = pydantic.Field(
        'functions.messages.GetSearchResultsCalendar',
        alias='_'
    )

    peer: "base.InputPeer"
    filter: "base.MessagesFilter"
    offset_id: int
    offset_date: Datetime
    saved_peer_id: typing.Optional["base.InputPeer"] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class TermsOfService(BaseModel):
    """
    types.help.TermsOfService
    ID: 0x780a0310
    Layer: 181
    """
    QUALNAME: typing.Literal['types.help.TermsOfService', 'TermsOfService'] = pydantic.Field(
        'types.help.TermsOfService',
        alias='_'
    )

    id: "base.DataJSON"
    text: str
    entities: list["base.MessageEntity"]
    popup: typing.Optional[bool] = None
    min_age_confirm: typing.Optional[int] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class GetBlocked(BaseModel):
    """
    functions.contacts.GetBlocked
    ID: 0x9a868f80
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.contacts.GetBlocked', 'GetBlocked'] = pydantic.Field(
        'functions.contacts.GetBlocked',
        alias='_'
    )

    offset: int
    limit: int
    my_stories_from: typing.Optional[bool] = None



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class StoryView(BaseModel):
    """
    types.StoryView
    ID: 0xb0bdeac5
    Layer: 181
    """
    QUALNAME: typing.Literal['types.StoryView', 'StoryView'] = pydantic.Field(
        'types.StoryView',
        alias='_'
    )

    user_id: int
    date: Datetime
    blocked: typing.Optional[bool] = None
    blocked_my_stories_from: typing.Optional[bool] = None
    reaction: typing.Optional["base.Reaction"] = None



from __future__ import annotations

import typing

import pydantic

from telegram_pydantic import types
from telegram_pydantic.utils import base_type_discriminator

# StoryView - Layer 181
StoryView = typing.Annotated[
    typing.Union[
        typing.Annotated[types.StoryView, pydantic.Tag('StoryView')],
        typing.Annotated[types.StoryViewPublicForward, pydantic.Tag('StoryViewPublicForward')],
        typing.Annotated[types.StoryViewPublicRepost, pydantic.Tag('StoryViewPublicRepost')]
    ],
    pydantic.Discriminator(base_type_discriminator)
]



from __future__ import annotations

import typing
from datetime import datetime

import pydantic

from telegram_pydantic.core import BaseModel
from telegram_pydantic.primitives import Bytes
from telegram_pydantic.primitives import Datetime

if typing.TYPE_CHECKING:
    from telegram_pydantic import base


class SendReaction(BaseModel):
    """
    functions.stories.SendReaction
    ID: 0x7fd736b2
    Layer: 181
    """
    QUALNAME: typing.Literal['functions.stories.SendReaction', 'SendReaction'] = pydantic.Field(
        'functions.stories.SendReaction',
        alias='_'
    )

    peer: "base.InputPeer"
    story_id: int
    reaction: "base.Reaction"
    add_to_recent: typing.Optional[bool] = None
